#!/usr/bin/env python

from distutils.core import setup

setup(
    name='automain',
    version='1.1',
    description='A shortcut for "if __name__ == \"main\":"',
    author='Gerald Kaszuba',
    author_email='automain@gakman.com',
    packages=['automain'],
    )
